<?php
header('Content-Type: application/json');
include_once '../db/database/conn.php';

try {
    $db = new DBConn();
    $conn = $db->getConnection();

    // Get query parameters
    $classes_id = $_GET['classes_id'] ?? null;
    $email = $_GET['email'] ?? null;
    $start_date = $_GET['start_date'] ?? null;
    $end_date = $_GET['end_date'] ?? null;
    $status = $_GET['status'] ?? null;
    $search = $_GET['search'] ?? null;

    if (!$classes_id || !$email) {
        throw new Exception('Required parameters missing');
    }

    // Base query
    $query = "SELECT 
                student_name, 
                form_no, 
                attendance_status, 
                created_at,
                DATE(created_at) as date
              FROM student_attendance
              WHERE classes_id = ? AND email = ?";

    $params = [$classes_id, $email];
    $types = "is";

    // Add date filter if provided
    if ($start_date && $end_date) {
        $query .= " AND DATE(created_at) BETWEEN ? AND ?";
        $params[] = $start_date;
        $params[] = $end_date;
        $types .= "ss";
    }

    // Add status filter if provided
    if ($status) {
        $query .= " AND attendance_status = ?";
        $params[] = $status;
        $types .= "s";
    }

    // Add search filter if provided
    if ($search) {
        $query .= " AND (student_name LIKE ? OR form_no LIKE ?)";
        $searchTerm = "%$search%";
        $params[] = $searchTerm;
        $params[] = $searchTerm;
        $types .= "ss";
    }

    $query .= " ORDER BY created_at DESC";

    // Prepare and execute query
    $stmt = $conn->prepare($query);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $result = $stmt->get_result();

    $attendance = [];
    while ($row = $result->fetch_assoc()) {
        $attendance[] = $row;
    }

    // Calculate summary statistics
    $summary = calculateSummary($conn, $classes_id, $email, $start_date, $end_date);

    echo json_encode([
        'success' => true,
        'attendance' => $attendance,
        'summary' => $summary
    ]);

} catch (Exception $e) {
    http_response_code(400);
    echo json_encode([
        'success' => false,
        'message' => $e->getMessage()
    ]);
}

function calculateSummary($conn, $classes_id, $email, $start_date, $end_date) {
    // Total unique days
    $daysQuery = "SELECT COUNT(DISTINCT DATE(created_at)) as total_days 
                  FROM student_attendance 
                  WHERE classes_id = ? AND email = ?";
    $params = [$classes_id, $email];
    $types = "is";
    
    if ($start_date && $end_date) {
        $daysQuery .= " AND DATE(created_at) BETWEEN ? AND ?";
        $params[] = $start_date;
        $params[] = $end_date;
        $types .= "ss";
    }
    
    $stmt = $conn->prepare($daysQuery);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $total_days = $stmt->get_result()->fetch_assoc()['total_days'];
    
    // Total records
    $recordsQuery = "SELECT COUNT(*) as total_records 
                     FROM student_attendance 
                     WHERE classes_id = ? AND email = ?";
    $params = [$classes_id, $email];
    $types = "is";
    
    if ($start_date && $end_date) {
        $recordsQuery .= " AND DATE(created_at) BETWEEN ? AND ?";
        $params[] = $start_date;
        $params[] = $end_date;
        $types .= "ss";
    }
    
    $stmt = $conn->prepare($recordsQuery);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $total_records = $stmt->get_result()->fetch_assoc()['total_records'];
    
    // Average attendance percentage
    $attendanceQuery = "SELECT 
                            (SUM(CASE WHEN attendance_status = 'উপস্থিত' THEN 1 ELSE 0 END) / COUNT(*)) * 100 as avg_attendance
                         FROM student_attendance
                         WHERE classes_id = ? AND email = ?";
    $params = [$classes_id, $email];
    $types = "is";
    
    if ($start_date && $end_date) {
        $attendanceQuery .= " AND DATE(created_at) BETWEEN ? AND ?";
        $params[] = $start_date;
        $params[] = $end_date;
        $types .= "ss";
    }
    
    $stmt = $conn->prepare($attendanceQuery);
    $stmt->bind_param($types, ...$params);
    $stmt->execute();
    $avg_attendance = round($stmt->get_result()->fetch_assoc()['avg_attendance'], 1);
    
    return [
        'total_days' => $total_days,
        'total_records' => $total_records,
        'average_attendance' => $avg_attendance
    ];
}
?>